aboutsummaryrefslogtreecommitdiffhomepage
path: root/Eigen/src/plugins/BlockMethods.h
diff options
context:
space:
mode:
authorGravatar Gael Guennebaud <g.gael@free.fr>2012-12-24 13:33:22 +0100
committerGravatar Gael Guennebaud <g.gael@free.fr>2012-12-24 13:33:22 +0100
commitf41d96deb9b64e74cd2d8c48a698f4443ce9bbab (patch)
treebb36884185b0bfa99c16338403fc5736cbd7eba9 /Eigen/src/plugins/BlockMethods.h
parentf450303321c4d37d908d5d9e6fcf480f27bf53e3 (diff)
Fix several documentation issues
Diffstat (limited to 'Eigen/src/plugins/BlockMethods.h')
-rw-r--r--Eigen/src/plugins/BlockMethods.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/Eigen/src/plugins/BlockMethods.h b/Eigen/src/plugins/BlockMethods.h
index 3414c1dd1..19a491cf7 100644
--- a/Eigen/src/plugins/BlockMethods.h
+++ b/Eigen/src/plugins/BlockMethods.h
@@ -584,7 +584,7 @@ inline ConstRowXpr row(Index i) const
* \only_for_vectors
*
* \param start the first coefficient in the segment
* \param size the number of coefficients in the segment
*
* Example: \include MatrixBase_segment_int_int.cpp
* Output: \verbinclude MatrixBase_segment_int_int.out
@@ -613,7 +613,7 @@ inline ConstSegmentReturnType segment(Index start, Index vecSize) const
*
* \only_for_vectors
*
* \param size the number of coefficients in the block
*
* Example: \include MatrixBase_start_int.cpp
* Output: \verbinclude MatrixBase_start_int.out
@@ -624,10 +624,10 @@ inline ConstSegmentReturnType segment(Index start, Index vecSize) const
*
* \sa class Block, block(Index,Index)
*/
-inline SegmentReturnType head(Index vecsize)
+inline SegmentReturnType head(Index vecSize)
{
EIGEN_STATIC_ASSERT_VECTOR_ONLY(Derived)
- return SegmentReturnType(derived(), 0, vecsize);
+ return SegmentReturnType(derived(), 0, vecSize);
}
/** This is the const version of head(Index).*/
@@ -642,7 +642,7 @@ inline ConstSegmentReturnType
*
* \only_for_vectors
*
* \param size the number of coefficients in the block
*
* Example: \include MatrixBase_end_int.cpp
* Output: \verbinclude MatrixBase_end_int.out
@@ -584,7 +584,7 @@ inline ConstRowXpr row(Index i) const
*
* \param start the first coefficient in the segment
- * \param size the number of coefficients in the segment
+ * \param vecSize the number of coefficients in the segment
*
* Example: \include MatrixBase_segment_int_int.cpp
@@ -613,7 +613,7 @@ inline ConstSegmentReturnType segment(Index start, Index vecSize) const
* \only_for_vectors
*
- * \param size the number of coefficients in the block
+ * \param vecSize the number of coefficients in the block
*
* Example: \include MatrixBase_start_int.cpp
@@ -642,7 +642,7 @@ inline ConstSegmentReturnType
* \only_for_vectors
*
- * \param size the number of coefficients in the block
+ * \param vecSize the number of coefficients in the block
*
* Example: \include MatrixBase_end_int.cpp